<?php
/*
Plugin Name: Unique List For Gravity Forms
Plugin URI: https://wordpress.org/plugins/gf-unique-list
Version: 1.0.6
Description: Add a unique piece of text or code to each gravity form from a predefined list.
Author: James Low
Author URI: http://jameslow.com
*/

class GFUniqueList {
	public static function add_hooks() {
		add_action('gform_loaded', array('GFUniqueList', 'gform_loaded'), 5);
		add_action('gform_pre_submission', array('GFUniqueList', 'pre_submission'), 10, 1);
	}
	public static function get_settings_query($form) {
		$form = is_array($form) ? $form : GFAPI::get_form($form);
		return isset($form['gf-unique-list']) ? $form['gf-unique-list'] : array();
	}
	public static function get_items($form, $settings = null) {
		$settings = $settings ? $settings : self::get_settings_query($form);
		$items = explode("\n", $settings['unique_items']);
		$results = array();
		foreach ($items as $item) {
			$item = trim($item);
			if ($item != '') {
				$results[] = $item;
			}
		}
		return $results;
	}
	public static function pre_submission($form) {
		$settings = self::get_settings_query($form);
		if (isset($settings['enabled']) && $settings['enabled'] == '1') {
			$field = $settings['fields_unique_field'];
			if ($field != '' || $field != null) {
				global $wpdb;
				$form_id = $form['id'];
				$table = $wpdb->prefix . 'gf_entry_meta';
				$items = self::get_items($form, $settings);
				$sql = "SELECT meta_value FROM $table WHERE form_id = '$form_id' AND meta_key = '$field'";
				$values = $wpdb->get_col($sql);
				$values = $values ? $values : array();
				foreach ($items as $item) {
					if (!in_array($item, $values)) {
						$_POST['input_'.$field] = $item;
						return;
					}
				}
			}
		}
	}
	public static function gform_loaded() {
		require_once 'gf-unique-list-addon.php';
		GFAddOn::register('GFUniqueListAddon');
	}
	public static function log($obj) {
		error_log(print_r($obj, true));
	}
}
GFUniqueList::add_hooks();